function [update_upper,z0] = poly_perform_test(K,B,alpha,delta,eta)
% Copyright by Emre Mengi
% call : [f,z] = poly_perform_test(K,B,delta,eta)
% auxiliary routine called by poly_dist_uncont to
% check which one of
%           delta1 >= tau(K,B) or
%           delta2 < tau(K,B)
% holds.

% we don't check for errors; this is already done by
% the main routine.
[n,nc,mp] = size(K);
m = mp-1;
Bhat = B*B'/delta - delta*eye(n);
In = eye(n);
Zn = zeros(n,n);

realtol = 10^-8;
smalltol  = 10^-10;




% test: find the intersection points of the rays with
%       various slopes and the level sets of
%       f(re^i theta) = sigma_n [P(re^itheta)/q(r) B]. The 
%       slopes are ranging from 0 to pi with the 
%       difference between two successive ones is eta.

% If any intersection point is found delta1=delta >= tau.

for theta = 0:eta:pi

  for j = 0:2*m

    if j == 0
        Q(:,:,j+1) = [-delta*alpha(j+1)^2*In K(:,:,j+1)'; ...
                       K(:,:,j+1)  Bhat];
    else
        if (j <= m)
            if mod(j,2) % j is odd, Qj is skew-Hermitian
                Q(:,:,j+1) = [ Zn (-1)^((j-1)/2)*-i*K(:,:,j+1)'*exp(-i*j*theta); ...
                        (-1)^((j-1)/2)*-i*K(:,:,j+1)*exp(i*j*theta) Zn];
            else % j is even, Qj is Hermitian
                Q(:,:,j+1) = [ -delta*alpha(j/2+1)^2*In*(-1)^(j/2) ...
                            (-1)^(j/2)*K(:,:,j+1)'*exp(-i*j*theta); ...
                            (-1)^(j/2)*K(:,:,j+1)*exp(i*j*theta) ...
                            Zn];
            end
        else
            if mod(j,2) % j is odd and greater than half of the degree
                Q(:,:,j+1) = zeros(2*n,2*n);
            else % if j is even and greater than half of the degree
                Q(:,:,j+1) = [ -delta*alpha(j/2+1)^2*In*(-1)^(j/2) Zn; Zn Zn];
            end
        end
    end
  end
   
    % extract the real eigenvalues of Q
    eigsQ = mypolyeig(Q);
    imagindx = find(abs(real(eigsQ)) < realtol & eigsQ ~= inf & eigsQ ~= -inf);
    imageigsQ = imag(eigsQ(imagindx));
    
    % this minimum singular value test is needed just
    % to retrieve a point z where delta=f(z) is attained.
    for j=1:length(imageigsQ)
        mins = compute_rect_sing(K,B,alpha,imageigsQ(j)*exp(i*theta));
            
        if abs(mins-delta) < smalltol
            update_upper = 1;
            z0 = imageigsQ(j)*exp(i*theta);
            return;
        end
    end
    
    


end

% If none of the rays is intersecting the delta-level set,
% then tau > delta2.

update_upper = 0;
z0 = 0;
return;