function f = compute_rect_sing(K,B,alpha,lambda)
% Copyright by Emre Mengi
% call : f = compute_rect_sing(K,B,alpha,lambda)
%
% K      :   Sequence of matrices of size (nxn).
% B      :   Coefficient matrix (nxm, n<=m) for the input.
% alpha  :   The vector of scaling factors.
% lambda :   A point in the complex plane where the
%            function is supposed to be computed.

[n,nc,m] = size(K);
[alr,alc] = size(alpha);

if n ~= nc
    error('input polynomial must be square')
end

if alr ~= 1
    error('alpha is a row vector')
end

if alc ~= m
    error('size of alpha must be equal to the order of the system')
end

KT = zeros(n,n);
qt = 0;
for j = 1:m
    qt = qt + alpha(j)^2*abs(lambda)^(2*(j-1));
    KT = KT + lambda^(j-1)*K(:,:,j);
end

f = min(svd([KT/sqrt(qt) B]));
return;