function [alpha,wbest] = poly_cdi_alpha(P,gamma,wmid)
% Michael Overton and Emre Mengi (Last updated July 1 2006)
%
% called by poly_cdi.m
%
% Computes f(w) = sigma_min P(w)/p_gamma(|w|) at each point w in wmid.
% Returns alpha = min{f(w)| w in wmid} and wbest satisfying 
% f(wbest) = alpha.
%
% Input:
%       P       : Input matrix polynomial(nxnxk)
%       gamma   : Vector of scaling factors
%       wmid    : Set of midpoints
%
% Output:
%       alpha   : Minimum function value among the function
%                 values at midpoints.
%       wbest   : One of the midpoints at which the function
%                 value is minimum.



[nr,nc,kp] = size(P);
if nr ~= nc
    error('poly_cdi_alpha: P must be square')
end

for j = 1:length(wmid)
    % compute f(w) at the jth midpoint in wmid
    alphamin(j) = compute_sing(P,gamma,wmid(j)*i);
end

% min of min singular values
[minval,minind] = min(alphamin);

% set the return variables
alpha = minval;
wbest = wmid(minind);

return;