function f = compute_sing(P,gamma,lambda)
% Copyright by Emre Mengi
% call : f = compute_sing(P,gamma,lambda)
% task : computes sigma_min(P(lambda)/p_gamma(|lambda|))
%        where p_gamma(x) = sum_j=0^k gamma_j^2 x^2j.  
%
% K      :   Sequence of matrices of size (nxn).
% B      :   Coefficient matrix (nxm, n<=m) for the input.
% alpha  :   The vector of scaling factors.
% lambda :   A point in the complex plane where the
%            function is supposed to be computed.

[n,nc,kp] = size(P);
[alr,alc] = size(gamma);

if n ~= nc
    error('input polynomial must be square')
end

if alr ~= 1
    error('gamma is a row vector')
end

if alc ~= kp
    error('size of gamma must be equal to the order of the system')
end

PT = zeros(n,n);
qt = 0;
for j = 0:(kp-1)
    qt = qt + gamma(j+1)^2*abs(lambda)^(2*j);
    PT = PT + lambda^j*P(:,:,j+1);
end

f = min(svd(PT))/sqrt(qt);
return;