function [] = plot_cdi(A,plotfig,lowr,highr)
% call : plot_cdi(A,plotfig,lowr,highr)
%   task
%                 Plots the function f(w)=svd_{min}(A-wiI) with domain
%                 restricted to the interval [lowr,highr]
%
%   input
%       A       : Input matrix.(must be square)
%       plotfig : figure handle, if no figure with this handle
%                 exists, a new figure will be opened, otherwise
%                 the circle will be drawn on the figure with
%                 handle plotfig.
%       lowr    : Lower bound for the domain.
%       highr   : Upper bound for the domain.
%
%   output
%                 no output


% error checks
if (highr <= lowr)
    error('Higher bound for the domain should be greater than the lower bound');
end

n = length(A);
if size(A) ~= [n n]
   error('A must be square')
end
In = eye(n);



% the imaginary axis is discretized, the length between two successive
% points is arranged so that there are 1000 points selected.
number_of_points = 1000;
% disc_int is the distance between two successive selected points on the
% imaginary axis.
disc_int = (highr - lowr) / number_of_points;


w = lowr;
wv = [];
fv = [];
while w < highr
    f = min(svd(A-w*i*In));
    wv = [wv w];
    fv = [fv f];
    w = w + disc_int;
end

figure(plotfig);
plot(wv,fv,'r-');