function [] = plot_poly_ddi(P,gamma,plotfig,lowr,highr)
% Copyright Emre Mengi, July 2006
% call : plot_poly_ddi(P,gamma,plotfig,lowr,highr)
%   task
%                 Plots the function f(w)=svd_{min}P(e^(itheta))/ ||gamma|| 
%                 with domain restricted to the interval [lowr,highr]
%
%   input
%       P       : Input matrix polynomial.(nxnxk)
%       gamma   : Vector of nonnegative scalars of size k
%       plotfig : figure handle, if no figure with this handle
%                 exists, a new figure will be opened, otherwise
%                 the circle will be drawn on the figure with
%                 handle plotfig.
%       lowr    : Lower bound for the domain.
%       highr   : Upper bound for the domain.
%
%   output
%                 no output


% error checks
if (highr <= lowr)
    error('Higher bound for the domain should be greater than the lower bound');
end

[nr,nc,kp] = size(P);
if nr ~= nc
   error('P must be square')
end
n = nr;
k = kp-1;
In = eye(n);



% the imaginary axis is discretized, the length between two successive
% points is arranged so that there are 1000 points selected.
number_of_points = 1000;
% disc_int is the distance between two successive selected points on the
% imaginary axis.
disc_int = (highr - lowr) / number_of_points;


w = lowr;
wv = [];
fv = [];
while w < highr
    f = compute_sing(P,gamma,exp(w*i));
    wv = [wv w];
    fv = [fv f];
    w = w + disc_int;
end

figure(plotfig);
plot(wv,fv,'b-');